# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: users/v1/User.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'users/v1/User.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13users/v1/User.proto\x12\x17\x64iscord_protos.users.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe0\xba\x02\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x15\n\rdiscriminator\x18\x03 \x01(\t\x12\x31\n\x06\x61vatar\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x88\x01\x01\x12\x0b\n\x03\x62ot\x18\x05 \x01(\x08\x12\x14\n\x0cpublic_flags\x18\x06 \x01(\x04\x12\x36\n\x0bglobal_name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x88\x01\x01\x12W\n\x16\x61vatar_decoration_data\x18\t \x01(\x0b\x32\x32.discord_protos.users.v1.User.UserAvatarDecorationH\x02\x88\x01\x01\x12J\n\rprimary_guild\x18\n \x01(\x0b\x32..discord_protos.users.v1.User.UserPrimaryGuildH\x03\x88\x01\x01\x12I\n\x0c\x63ollectibles\x18\x0b \x01(\x0b\x32..discord_protos.users.v1.User.UserCollectiblesH\x04\x88\x01\x01\x12\x44\n\x0csafety_state\x18\x0c \x01(\x0b\x32).discord_protos.users.v1.User.SafetyStateH\x05\x88\x01\x01\x12Q\n\x13\x64isplay_name_styles\x18\r \x01(\x0b\x32/.discord_protos.users.v1.User.DisplayNameStylesH\x06\x88\x01\x01\x1a\xa9\x01\n\x14UserAvatarDecoration\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x31\n\x06sku_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x00\x88\x01\x01\x12\x35\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueH\x01\x88\x01\x01\x42\t\n\x07_sku_idB\r\n\x0b_expires_at\x1a\xaa\x02\n\x10UserPrimaryGuild\x12<\n\x11identity_guild_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x00\x88\x01\x01\x12\x39\n\x10identity_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x01\x88\x01\x01\x12.\n\x03tag\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x02\x88\x01\x01\x12\x30\n\x05\x62\x61\x64ge\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x03\x88\x01\x01\x42\x14\n\x12_identity_guild_idB\x13\n\x11_identity_enabledB\x06\n\x04_tagB\x08\n\x06_badge\x1a\xc0\x01\n\rUserNameplate\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x0f\n\x07palette\x18\x02 \x01(\t\x12\x31\n\x06sku_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x00\x88\x01\x01\x12\x33\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\r\n\x05label\x18\x05 \x01(\tB\t\n\x07_sku_idB\r\n\x0b_expires_at\x1a\x65\n\x10UserCollectibles\x12\x43\n\tnameplate\x18\x01 \x01(\x0b\x32+.discord_protos.users.v1.User.UserNameplateH\x00\x88\x01\x01\x42\x0c\n\n_nameplate\x1a\r\n\x0bNormalState\x1a\x61\n\x0fRestrictedState\x12\x39\n\x10restricted_until\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x13\n\x11_restricted_until\x1ao\n\x13\x44\x65\x66\x65rredActionState\x12>\n\x15\x61\x63tion_deferred_until\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x18\n\x16_action_deferred_until\x1a\xa9\x01\n\x0fTempBannedState\x12\x35\n\x0c\x62\x61nned_until\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12N\n\x14\x63lassification_types\x18\x02 \x03(\x0e\x32\x30.discord_protos.users.v1.User.ClassificationTypeB\x0f\n\r_banned_until\x1a]\n\x0b\x42\x61nnedState\x12N\n\x14\x63lassification_types\x18\x01 \x03(\x0e\x32\x30.discord_protos.users.v1.User.ClassificationType\x1a\xc2\x04\n\x0bSafetyState\x12;\n\x06normal\x18\x65 \x01(\x0b\x32).discord_protos.users.v1.User.NormalStateH\x00\x12\x43\n\nrestricted\x18\x66 \x01(\x0b\x32-.discord_protos.users.v1.User.RestrictedStateH\x00\x12L\n\x0f\x64\x65\x66\x65rred_action\x18g \x01(\x0b\x32\x31.discord_protos.users.v1.User.DeferredActionStateH\x00\x12\x44\n\x0btemp_banned\x18h \x01(\x0b\x32-.discord_protos.users.v1.User.TempBannedStateH\x00\x12;\n\x06\x62\x61nned\x18i \x01(\x0b\x32).discord_protos.users.v1.User.BannedStateH\x00\x12?\n\x06reason\x18\x01 \x01(\x0e\x32/.discord_protos.users.v1.User.SafetyStateReason\x12\x44\n\x0b\x61nnotations\x18\x02 \x03(\x0e\x32/.discord_protos.users.v1.User.SafetyAnnotations\x12;\n\x10last_mutation_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueH\x01\x88\x01\x01\x42\x07\n\x05stateB\x13\n\x11_last_mutation_id\x1a\xa7\x01\n\x11\x44isplayNameStyles\x12>\n\x07\x66ont_id\x18\x01 \x01(\x0e\x32-.discord_protos.users.v1.User.DisplayNameFont\x12\x42\n\teffect_id\x18\x02 \x01(\x0e\x32/.discord_protos.users.v1.User.DisplayNameEffect\x12\x0e\n\x06\x63olors\x18\x03 \x03(\r\"\xe2\x96\x02\n\x12\x43lassificationType\x12#\n\x1f\x43LASSIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43LASSIFICATION_TYPE_UNKNOWN\x10\x01\x12/\n+CLASSIFICATION_TYPE_UNSOLICITED_PORNOGRAPHY\x10\x64\x12\x32\n-CLASSIFICATION_TYPE_NONCONSENSUAL_PORNOGRAPHY\x10\xc8\x01\x12,\n\'CLASSIFICATION_TYPE_GLORIFYING_VIOLENCE\x10\xd2\x01\x12$\n\x1f\x43LASSIFICATION_TYPE_HATE_SPEECH\x10\xdc\x01\x12)\n$CLASSIFICATION_TYPE_CRACKED_ACCOUNTS\x10\xe6\x01\x12&\n!CLASSIFICATION_TYPE_ILLICIT_GOODS\x10\xf0\x01\x12+\n&CLASSIFICATION_TYPE_SOCIAL_ENGINEERING\x10\xfa\x01\x12<\n7CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SAFETY_DISPATCH\x10\x84\x02\x12\x36\n1CLASSIFICATION_TYPE_UNDERAGE_USER_SAFETY_DISPATCH\x10\x8e\x02\x12-\n(CLASSIFICATION_TYPE_CSAM_SAFETY_DISPATCH\x10\x98\x02\x12\x41\n<CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x9e\x02\x12<\n7CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_SAFETY_DISPATCH\x10\xa2\x02\x12W\nRCLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xa8\x02\x12:\n5CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_SAFETY_DISPATCH\x10\xac\x02\x12U\nPCLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xb2\x02\x12?\n:CLASSIFICATION_TYPE_HARASSMENT_AND_THREATS_SAFETY_DISPATCH\x10\xb6\x02\x12\x34\n/CLASSIFICATION_TYPE_HATE_SPEECH_SAFETY_DISPATCH\x10\xc0\x02\x12T\nOCLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xc6\x02\x12?\n:CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_SAFETY_DISPATCH\x10\xca\x02\x12S\nNCLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xd0\x02\x12\x42\n=CLASSIFICATION_TYPE_REGULATED_GOODS_HIGH_RISK_SAFETY_DISPATCH\x10\xd4\x02\x12\x44\n?CLASSIFICATION_TYPE_REGULATED_GOODS_MEDIUM_RISK_SAFETY_DISPATCH\x10\xde\x02\x12\x66\naCLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xe4\x02\x12\x41\n<CLASSIFICATION_TYPE_REGULATED_GOODS_LOW_RISK_SAFETY_DISPATCH\x10\xe8\x02\x12\x37\n2CLASSIFICATION_TYPE_FRAUD_SERVICES_SAFETY_DISPATCH\x10\xf2\x02\x12K\nFCLASSIFICATION_TYPE_FRAUD_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xf8\x02\x12\x38\n3CLASSIFICATION_TYPE_FINANCIAL_SCAMS_SAFETY_DISPATCH\x10\xfc\x02\x12:\n5CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_SAFETY_DISPATCH\x10\x86\x03\x12Q\nLCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH\x10\x90\x03\x12\x65\n`CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x96\x03\x12Q\nLCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_SAFETY_DISPATCH\x10\x9a\x03\x12\x65\n`CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xa0\x03\x12:\n5CLASSIFICATION_TYPE_TRANSACTION_SCAMS_SAFETY_DISPATCH\x10\xa4\x03\x12:\n5CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_HASH_MATCH\x10\xf4\x03\x12\x38\n3CLASSIFICATION_TYPE_CSAM_HIGH_CONFIDENCE_HASH_MATCH\x10\xf5\x03\x12?\n:CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_SAFETY_DISPATCH\x10\xfe\x03\x12\x44\n?CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_SAFETY_DISPATCH\x10\x88\x04\x12X\nSCLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x8e\x04\x12K\nFCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_SAFETY_DISPATCH\x10\x92\x04\x12_\nZCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x98\x04\x12V\nQCLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH\x10\x9c\x04\x12Q\nLCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH\x10\xa6\x04\x12\x65\n`CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xac\x04\x12\x46\nACLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_SAFETY_DISPATCH\x10\xb0\x04\x12\x41\n<CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_SAFETY_DISPATCH\x10\xba\x04\x12U\nPCLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xc0\x04\x12:\n5CLASSIFICATION_TYPE_SUICIDE_PROMOTION_SAFETY_DISPATCH\x10\xc4\x04\x12N\nICLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xca\x04\x12<\n7CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_SAFETY_DISPATCH\x10\xce\x04\x12P\nKCLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xd4\x04\x12\x42\n=CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_SAFETY_DISPATCH\x10\xd8\x04\x12\x36\n1CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_API\x10\xd9\x04\x12V\nQCLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xde\x04\x12>\n9CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_SAFETY_DISPATCH\x10\xe2\x04\x12\x63\n^CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_SAFETY_DISPATCH\x10\xec\x04\x12T\nOCLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_SAFETY_DISPATCH\x10\xf6\x04\x12G\nBCLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_SAFETY_DISPATCH\x10\x80\x05\x12;\n6CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_API\x10\x81\x05\x12[\nVCLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x86\x05\x12Y\nTCLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_SAFETY_DISPATCH\x10\x8a\x05\x12=\n8CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_HASH_MATCH\x10\x94\x05\x12\x42\n=CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_SAFETY_DISPATCH\x10\x95\x05\x12:\n5CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_SAFETY_DISPATCH\x10\x9e\x05\x12N\nICLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xa4\x05\x12\x39\n4CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_SAFETY_DISPATCH\x10\xa8\x05\x12M\nHCLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xae\x05\x12\x36\n1CLASSIFICATION_TYPE_IMPERSONATION_SAFETY_DISPATCH\x10\xde,\x12\x46\nACLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SAFETY_DISPATCH\x10\xdf,\x12\x46\nACLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SAFETY_DISPATCH\x10\xb2\x05\x12Z\nUCLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xb8\x05\x12\x31\n,CLASSIFICATION_TYPE_PHISHING_SAFETY_DISPATCH\x10\xbc\x05\x12\x36\n1CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SMITE\x10\xc6\x05\x12@\n;CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SAFETY_DISPATCH\x10\xc7\x05\x12\x36\n1CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_ADMIN\x10\xc8\x05\x12\x33\n.CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_SMITE\x10\xd0\x05\x12H\nCCLASSIFICATION_TYPE_GENERIC_CHILD_SELF_ENDANGERMENT_SAFETY_DISPATCH\x10\xda\x05\x12M\nHCLASSIFICATION_TYPE_GENERIC_CSAM_AND_CHILD_SEXUALIZATION_SAFETY_DISPATCH\x10\xe4\x05\x12h\ncCLASSIFICATION_TYPE_GENERIC_INAPPROPRIATE_SEXUAL_CONDUCT_WITH_CHILDREN_AND_GROOMING_SAFETY_DISPATCH\x10\xee\x05\x12@\n;CLASSIFICATION_TYPE_GENERIC_FINANCIAL_SCAMS_SAFETY_DISPATCH\x10\xf8\x05\x12?\n:CLASSIFICATION_TYPE_GENERIC_FRAUD_SERVICES_SAFETY_DISPATCH\x10\x82\x06\x12P\nKCLASSIFICATION_TYPE_GENERIC_BULLYING_HARASSMENT_AND_THREATS_SAFETY_DISPATCH\x10\x8c\x06\x12<\n7CLASSIFICATION_TYPE_GENERIC_HATE_SPEECH_SAFETY_DISPATCH\x10\x96\x06\x12T\nOCLASSIFICATION_TYPE_GENERIC_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH\x10\xa0\x06\x12V\nQCLASSIFICATION_TYPE_GENERIC_SELF_HARM_ENCOURAGEMENT_AND_PROMOTION_SAFETY_DISPATCH\x10\xaa\x06\x12Y\nTCLASSIFICATION_TYPE_GENERIC_GLORIFICATION_AND_INCITEMENT_OF_VIOLENCE_SAFETY_DISPATCH\x10\xb4\x06\x12;\n6CLASSIFICATION_TYPE_GENERIC_CYBERCRIME_SAFETY_DISPATCH\x10\xbe\x06\x12q\nlCLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xce\x06\x12\x36\n1CLASSIFICATION_TYPE_VIOLENT_MEDIA_SAFETY_DISPATCH\x10\xd2\x06\x12J\nECLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xd8\x06\x12s\nnCLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xe2\x06\x12_\nZCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xec\x06\x12Y\nTCLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xf6\x06\x12\x43\n>CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_SAFETY_DISPATCH\x10\xfa\x06\x12I\nDCLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH\x10\xff\x06\x12W\nRCLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x80\x07\x12G\nBCLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH\x10\x84\x07\x12M\nHCLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH\x10\x89\x07\x12[\nVCLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x8a\x07\x12\x43\n>CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_SAFETY_DISPATCH\x10\x8e\x07\x12I\nDCLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH\x10\x93\x07\x12W\nRCLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x94\x07\x12G\nBCLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH\x10\x98\x07\x12M\nHCLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH\x10\x9d\x07\x12[\nVCLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\x9e\x07\x12-\n(CLASSIFICATION_TYPE_GORE_SAFETY_DISPATCH\x10\xa2\x07\x12Z\nUCLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xa8\x07\x12M\nHCLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_SAFETY_DISPATCH\x10\xac\x07\x12S\nNCLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_SAFETY_DISPATCH\x10\xb1\x07\x12\x61\n\\CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xb2\x07\x12@\n;CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_SAFETY_DISPATCH\x10\xb6\x07\x12\x46\nACLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_SAFETY_DISPATCH\x10\xbb\x07\x12T\nOCLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xbc\x07\x12\x43\n>CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_SAFETY_DISPATCH\x10\xc0\x07\x12I\nDCLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_SAFETY_DISPATCH\x10\xc5\x07\x12W\nRCLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xc6\x07\x12\x41\n<CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_SAFETY_DISPATCH\x10\xca\x07\x12G\nBCLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_SAFETY_DISPATCH\x10\xcf\x07\x12\x41\n<CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xd0\x07\x12\x64\n_CLASSIFICATION_TYPE_AGE_RESTRICTED_CONTENT_IN_SERVER_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xda\x07\x12#\n\x1e\x43LASSIFICATION_TYPE_CSAM_SMITE\x10\xb8\x17\x12)\n$CLASSIFICATION_TYPE_CSAM_GUILD_SMITE\x10\xbd\x17\x12.\n)CLASSIFICATION_TYPE_SUSPICIOUS_LINK_SMITE\x10\xc2\x17\x12<\n7CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SMITE\x10\xcc\x17\x12#\n\x1e\x43LASSIFICATION_TYPE_SPAM_SMITE\x10\xd6\x17\x12+\n&CLASSIFICATION_TYPE_SPAM_CEILING_SMITE\x10\xb0\x18\x12/\n*CLASSIFICATION_TYPE_VOLUMETRIC_ABUSE_SMITE\x10\xba\x18\x12\x33\n.CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_SMITE\x10\xe0\x17\x12\x32\n-CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_SMITE\x10\xea\x17\x12M\nHCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_SMITE\x10\xf9\x17\x12I\nDCLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_SMITE\x10\x83\x18\x12<\n7CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SMITE\x10\x8d\x18\x12\x42\n=CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_SMITE\x10\x92\x18\x12P\nKCLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SMITE\x10\x93\x18\x12;\n6CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_SMITE\x10\x9c\x18\x12<\n7CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_SMITE\x10\xa6\x18\x12>\n9CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_HIGH_RISK\x10\xa0\x1f\x12@\n;CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_MEDIUM_RISK\x10\xaa\x1f\x12@\n;CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_VERY_HIGH_RISK\x10\x84 \x12;\n6CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_HIGH_RISK\x10\x8e \x12=\n8CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_MEDIUM_RISK\x10\x98 \x12:\n5CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_LOW_RISK\x10\xa2 \x12;\n6CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_COPYRIGHT\x10\xac \x12>\n9CLASSIFICATION_TYPE_OWNER_OF_INAUTHENTIC_ENGAGEMENT_GUILD\x10\xb6 \x12#\n\x1e\x43LASSIFICATION_TYPE_CSAM_ADMIN\x10\x88\'\x12)\n$CLASSIFICATION_TYPE_CSAM_GUILD_ADMIN\x10\x8d\'\x12\x37\n2CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_ADMIN\x10\x8e\'\x12:\n5CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_ADMIN\x10\x92\'\x12@\n;CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_ADMIN\x10\x97\'\x12N\nICLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_ADMIN\x10\x98\'\x12\x38\n3CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_ADMIN\x10\x9c\'\x12>\n9CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_ADMIN\x10\xa1\'\x12L\nGCLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_ADMIN\x10\xa2\'\x12Y\nTCLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_ADMIN\x10\xa6\'\x12_\nZCLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_ADMIN\x10\xab\'\x12m\nhCLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_ADMIN\x10\xac\'\x12J\nECLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_ADMIN\x10\xb0\'\x12O\nJCLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_ADMIN\x10\xba\'\x12U\nPCLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_ADMIN\x10\xbf\'\x12\x39\n4CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_ADMIN\x10\xc4\'\x12?\n:CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_GUILD_ADMIN\x10\xc9\'\x12\x41\n<CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_ADMIN\x10\xce\'\x12G\nBCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_ADMIN\x10\xd3\'\x12U\nPCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_ADMIN\x10\xd4\'\x12\x34\n/CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_ADMIN\x10\xd8\'\x12:\n5CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_ADMIN\x10\xdd\'\x12L\nGCLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_ADMIN\x10\xe2\'\x12^\nYCLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_ADMIN\x10\xec\'\x12\x64\n_CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_ADMIN\x10\xf1\'\x12r\nmCLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_ADMIN\x10\xf2\'\x12G\nBCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_ADMIN\x10\xf6\'\x12M\nHCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_ADMIN\x10\xfb\'\x12[\nVCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_ADMIN\x10\xfc\'\x12G\nBCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_ADMIN\x10\x80(\x12M\nHCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_ADMIN\x10\x85(\x12[\nVCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_ADMIN\x10\x86(\x12G\nBCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_ADMIN\x10\x8a(\x12M\nHCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_ADMIN\x10\x8f(\x12[\nVCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_ADMIN\x10\x90(\x12\x30\n+CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_ADMIN\x10\x94(\x12\x36\n1CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_ADMIN\x10\x99(\x12\x44\n?CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_ADMIN\x10\x9a(\x12/\n*CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_ADMIN\x10\x9e(\x12\x35\n0CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_ADMIN\x10\xa3(\x12\x43\n>CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_ADMIN\x10\xa4(\x12<\n7CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_ADMIN\x10\xa8(\x12\x42\n=CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_ADMIN\x10\xad(\x12P\nKCLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_ADMIN\x10\xae(\x12\x30\n+CLASSIFICATION_TYPE_SUICIDE_PROMOTION_ADMIN\x10\xb2(\x12\x36\n1CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_ADMIN\x10\xb7(\x12\x44\n?CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_ADMIN\x10\xb8(\x12\x32\n-CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_ADMIN\x10\xbc(\x12\x38\n3CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_ADMIN\x10\xc1(\x12\x46\nACLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_ADMIN\x10\xc2(\x12\x39\n4CLASSIFICATION_TYPE_RISK_OF_PHYSICAL_SELF_HARM_ADMIN\x10\xc6(\x12,\n\'CLASSIFICATION_TYPE_VIOLENT_MEDIA_ADMIN\x10\xd0(\x12\x32\n-CLASSIFICATION_TYPE_VIOLENT_MEDIA_GUILD_ADMIN\x10\xd5(\x12@\n;CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_ADMIN\x10\xd6(\x12#\n\x1e\x43LASSIFICATION_TYPE_GORE_ADMIN\x10\xda(\x12)\n$CLASSIFICATION_TYPE_GORE_GUILD_ADMIN\x10\xdf(\x12\x37\n2CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_ADMIN\x10\xe0(\x12M\nHCLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_ADMIN\x10\xe4(\x12S\nNCLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_ADMIN\x10\xe9(\x12\x61\n\\CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_ADMIN\x10\xea(\x12X\nSCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_ADMIN\x10\xee(\x12^\nYCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_ADMIN\x10\xf3(\x12l\ngCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_ADMIN\x10\xf4(\x12U\nPCLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_ADMIN\x10\xf8(\x12[\nVCLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_ADMIN\x10\xfd(\x12i\ndCLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_ADMIN\x10\xfe(\x12\x30\n+CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_ADMIN\x10\x82)\x12+\n&CLASSIFICATION_TYPE_SERVER_RAIDS_ADMIN\x10\x8c)\x12\x31\n,CLASSIFICATION_TYPE_SERVER_RAIDS_GUILD_ADMIN\x10\x91)\x12?\n:CLASSIFICATION_TYPE_SERVER_RAIDS_NON_DEDICATED_GUILD_ADMIN\x10\x92)\x12@\n;CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_ADMIN\x10\x96)\x12\x46\nACLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_GUILD_ADMIN\x10\x9b)\x12T\nOCLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_NON_DEDICATED_GUILD_ADMIN\x10\x9c)\x12<\n7CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_ADMIN\x10\xa0)\x12\x42\n=CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_ADMIN\x10\xa5)\x12P\nKCLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_ADMIN\x10\xa6)\x12\x37\n2CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_ADMIN\x10\xaa)\x12=\n8CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_GUILD_ADMIN\x10\xaf)\x12K\nFCLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_ADMIN\x10\xb0)\x12\x39\n4CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_ADMIN\x10\xb4)\x12?\n:CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_GUILD_ADMIN\x10\xb9)\x12M\nHCLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_ADMIN\x10\xba)\x12\x36\n1CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_ADMIN\x10\xbe)\x12<\n7CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_ADMIN\x10\xc3)\x12J\nECLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_ADMIN\x10\xc4)\x12\x37\n2CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_ADMIN\x10\xc8)\x12=\n8CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_ADMIN\x10\xcd)\x12K\nFCLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_ADMIN\x10\xce)\x12;\n6CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_ADMIN\x10\xd2)\x12\x41\n<CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_ADMIN\x10\xd7)\x12O\nJCLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_ADMIN\x10\xdc)\x12U\nPCLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_ADMIN\x10\xe0)\x12\x63\n^CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_ADMIN\x10\xe2)\x12\x46\nACLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN\x10\xe6)\x12L\nGCLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN\x10\xeb)\x12H\nCCLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN\x10\xf0)\x12N\nICLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN\x10\xf5)\x12\\\nWCLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN\x10\xf6)\x12\x45\n@CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN\x10\xfa)\x12K\nFCLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN\x10\xff)\x12Y\nTCLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN\x10\x80*\x12W\nRCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_ADMIN\x10\x84*\x12]\nXCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_ADMIN\x10\x89*\x12k\nfCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_ADMIN\x10\x8a*\x12J\nECLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_ADMIN\x10\x8e*\x12P\nKCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_ADMIN\x10\x93*\x12^\nYCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_NON_DEDICATED_GUILD_ADMIN\x10\x94*\x12K\nFCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_ADMIN\x10\x98*\x12Q\nLCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_ADMIN\x10\x9d*\x12K\nFCLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_ADMIN\x10\xa2*\x12I\nDCLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_API\x10\xa3*\x12<\n7CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_ADMIN\x10\xac*\x12G\nBCLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_ADMIN\x10\xb6*\x12[\nVCLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_NON_DEDICATED_GUILD_ADMIN\x10\xbc*\x12\x43\n>CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_ADMIN\x10\xc0*\x12W\nRCLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_NON_DEDICATED_GUILD_ADMIN\x10\xc6*\x12;\n6CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_ADMIN\x10\xca*\x12O\nJCLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_NON_DEDICATED_GUILD_ADMIN\x10\xd0*\x12(\n#CLASSIFICATION_TYPE_TRADEMARK_ADMIN\x10\xd4*\x12.\n)CLASSIFICATION_TYPE_TRADEMARK_GUILD_ADMIN\x10\xd9*\x12<\n7CLASSIFICATION_TYPE_TRADEMARK_NON_DEDICATED_GUILD_ADMIN\x10\xda*\x12:\n5CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_ADMIN\x10\xde*\x12N\nICLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_NON_DEDICATED_GUILD_ADMIN\x10\xe4*\x12<\n7CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_ADMIN\x10\xe8*\x12\x42\n=CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_GUILD_ADMIN\x10\xed*\x12P\nKCLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_NON_DEDICATED_GUILD_ADMIN\x10\xee*\x12\x34\n/CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_ADMIN\x10\xf2*\x12:\n5CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_GUILD_ADMIN\x10\xf7*\x12H\nCCLASSIFICATION_TYPE_HEALTH_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN\x10\xf8*\x12\x33\n.CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_ADMIN\x10\xfc*\x12\x39\n4CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_ADMIN\x10\x81+\x12G\nBCLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN\x10\x82+\x12X\nSCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_ADMIN\x10\x86+\x12^\nYCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_ADMIN\x10\x8b+\x12l\ngCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_ADMIN\x10\x8c+\x12<\n7CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_ADMIN\x10\x90+\x12\x42\n=CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_ADMIN\x10\x95+\x12\x30\n+CLASSIFICATION_TYPE_TRANSACTION_SCAMS_ADMIN\x10\x9a+\x12\x36\n1CLASSIFICATION_TYPE_TRANSACTION_SCAMS_GUILD_ADMIN\x10\x9f+\x12\'\n\"CLASSIFICATION_TYPE_PHISHING_ADMIN\x10\xa4+\x12<\n7CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_ADMIN\x10\xae+\x12\x42\n=CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_ADMIN\x10\xb3+\x12P\nKCLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_ADMIN\x10\xb4+\x12H\nCCLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_ADMIN\x10\xb8+\x12N\nICLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_GUILD_ADMIN\x10\xbd+\x12\\\nWCLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_NON_DEDICATED_GUILD_ADMIN\x10\xbe+\x12/\n*CLASSIFICATION_TYPE_MONEY_LAUNDERING_ADMIN\x10\xc2+\x12\x35\n0CLASSIFICATION_TYPE_MONEY_LAUNDERING_GUILD_ADMIN\x10\xc7+\x12&\n!CLASSIFICATION_TYPE_FORGERY_ADMIN\x10\xcc+\x12,\n\'CLASSIFICATION_TYPE_FORGERY_GUILD_ADMIN\x10\xd1+\x12\x37\n2CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_ADMIN\x10\xd6+\x12=\n8CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_ADMIN\x10\xdb+\x12K\nFCLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_NON_DEDICATED_GUILD_ADMIN\x10\xdc+\x12\x37\n2CLASSIFICATION_TYPE_MISLEADING_ABUSE_REPORTS_ADMIN\x10\xe0+\x12\x37\n2CLASSIFICATION_TYPE_FRAUDULENT_LEGAL_PROCESS_ADMIN\x10\xea+\x12\x43\n>CLASSIFICATION_TYPE_HARASSMENT_OF_DISCORDS_SUPPORT_TEAMS_ADMIN\x10\xf4+\x12,\n\'CLASSIFICATION_TYPE_IMPERSONATION_ADMIN\x10\xfe+\x12\x32\n-CLASSIFICATION_TYPE_IMPERSONATION_GUILD_ADMIN\x10\x83,\x12\x33\n.CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_ADMIN\x10\x88,\x12\x39\n4CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_ADMIN\x10\x8d,\x12\x34\n/CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_ADMIN\x10\x92,\x12:\n5CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_GUILD_ADMIN\x10\x97,\x12=\n8CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_ADMIN\x10\x9c,\x12\x43\n>CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_GUILD_ADMIN\x10\xa1,\x12Q\nLCLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_ADMIN\x10\xa2,\x12\x41\n<CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_ADMIN\x10\xa6,\x12G\nBCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_ADMIN\x10\xab,\x12U\nPCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_ADMIN\x10\xac,\x12H\nCCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_ADMIN\x10\xb0,\x12N\nICLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_ADMIN\x10\xb5,\x12\\\nWCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_NON_DEDICATED_GUILD_ADMIN\x10\xb6,\x12R\nMCLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_ADMIN\x10\xbf,\x12;\n6CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_ADMIN\x10\xc4,\x12\x41\n<CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_ADMIN\x10\xc9,\x12O\nJCLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_ADMIN\x10\xca,\x12T\nOCLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN\x10\xd4,\x12S\nNCLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN\x10\xe7,\x12\x38\n3CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_ADMIN\x10\xec,\x12\x33\n.CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_ADMIN\x10\xf6,\x12\x32\n-CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_ADMIN\x10\x80-\x12\x39\n4CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_ADMIN\x10\x8a-\x12?\n:CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_ADMIN\x10\x8f-\x12M\nHCLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN\x10\x90-\x12=\n8CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_ADMIN\x10\x94-\x12\x43\n>CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN\x10\x99-\x12Q\nLCLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN\x10\x9a-\x12\x39\n4CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_ADMIN\x10\x9e-\x12?\n:CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_ADMIN\x10\xa3-\x12M\nHCLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN\x10\xa4-\x12=\n8CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_ADMIN\x10\xa8-\x12\x43\n>CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN\x10\xad-\x12Q\nLCLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN\x10\xae-\x12\x43\n>CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_ADMIN\x10\xb2-\x12I\nDCLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_ADMIN\x10\xb7-\x12W\nRCLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_ADMIN\x10\xb8-\x12\x36\n1CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_ADMIN\x10\xbc-\x12\x39\n4CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_ADMIN\x10\xc6-\x12<\n7CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_ADMIN\x10\xc1-\x12?\n:CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_ADMIN\x10\xcb-\x12J\nECLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_ADMIN\x10\xc2-\x12M\nHCLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_ADMIN\x10\xcc-\x12\x37\n2CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_ADMIN\x10\xd0-\x12=\n8CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_ADMIN\x10\xd5-\x12\x35\n0CLASSIFICATION_TYPE_DENIED_PARTY_SCREENING_ADMIN\x10\xda-\x12I\nDCLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_ADMIN\x10\xe9-\x12\x30\n+CLASSIFICATION_TYPE_FRAUDULENT_CHARGE_ADMIN\x10\xee-\x12K\nFCLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_ADMIN\x10\xf8-\x12Q\nLCLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD_ADMIN\x10\xfd-\x12W\nRCLASSIFICATION_TYPE_PRESENCE_IN_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD\x10\xa0.\x12T\nOCLASSIFICATION_TYPE_OWNER_OF_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD\x10\xaa.\x12\x37\n2CLASSIFICATION_TYPE_UNAUTHORIZED_TRANSACTION_ADMIN\x10\x82.\x12;\n6CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_ADMIN\x10\x8c.\x12<\n7CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_ADMIN\x10\x96.\x12+\n&CLASSIFICATION_TYPE_SPAM_CEILING_ADMIN\x10\xb4.\x12M\nHCLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL\x10\xdd\x36\x12O\nJCLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL\x10\xe7\x36\x12L\nGCLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL\x10\xf1\x36\x12Q\nLCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_RETOOL\x10\xfb\x36\x12\x43\n>CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_RETOOL\x10\x85\x37\x12>\n9CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_RETOOL\x10\x8f\x37\x12:\n5CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_RETOOL\x10\x99\x37\x12H\nCCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_RETOOL\x10\xa3\x37\x12O\nJCLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_RETOOL\x10\xad\x37\x12S\nNCLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_RETOOL\x10\xb7\x37\x12\x42\n=CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_RETOOL\x10\xc1\x37\x12\x42\n=CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_RETOOL\x10\xc6\x37\x12\x35\n0CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_RETOOL\x10\xd0\x37\x12;\n6CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_RETOOL\x10\xda\x37\x12Y\nTCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_RETOOL\x10\xe4\x37\x12\x34\n/CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_RETOOL\x10\xee\x37\x12Y\nTCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_RETOOL\x10\xf8\x37\x12$\n\x1f\x43LASSIFICATION_TYPE_CSAM_RETOOL\x10\x82\x38\x12\x38\n3CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_RETOOL\x10\x8c\x38\x12\x39\n4CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_RETOOL\x10\x96\x38\x12H\nCCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_RETOOL\x10\xcb\x37\x12;\n6CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_RETOOL\x10\xd5\x37\x12\x41\n<CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_RETOOL\x10\xdf\x37\x12_\nZCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_RETOOL\x10\xe9\x37\x12:\n5CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_RETOOL\x10\xf3\x37\x12_\nZCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_RETOOL\x10\xfd\x37\x12*\n%CLASSIFICATION_TYPE_CSAM_GUILD_RETOOL\x10\x87\x38\x12>\n9CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_RETOOL\x10\x91\x38\x12?\n:CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_RETOOL\x10\x9b\x38\x12V\nQCLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_RETOOL\x10\xcc\x37\x12I\nDCLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_NON_DEDICATED_GUILD_RETOOL\x10\xd6\x37\x12O\nJCLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_RETOOL\x10\xe0\x37\x12m\nhCLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_RETOOL\x10\xea\x37\x12H\nCCLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_RETOOL\x10\xf4\x37\x12m\nhCLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_RETOOL\x10\xfe\x37\x12\x38\n3CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_RETOOL\x10\x88\x38\x12L\nGCLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_RETOOL\x10\x92\x38\x12M\nHCLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_RETOOL\x10\x9c\x38\x12W\nRCLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_RETOOL\x10\xa0\x38\x12\x37\n2CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_RETOOL\x10\xaa\x38\x12=\n8CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_RETOOL\x10\xb4\x38\x12Z\nUCLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_RETOOL\x10\xbe\x38\x12=\n8CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_RETOOL\x10\xc8\x38\x12H\nCCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_RETOOL\x10\xd2\x38\x12H\nCCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_RETOOL\x10\xdc\x38\x12U\nPCLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL\x10\xe6\x38\x12T\nOCLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL\x10\xf0\x38\x12\x36\n1CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_RETOOL\x10\xfa\x38\x12L\nGCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_RETOOL\x10\x84\x39\x12\x34\n/CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_RETOOL\x10\x94\x37\x12X\nSCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_RETOOL\x10\x8e\x39\x12\x44\n?CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_RETOOL\x10\x98\x39\x12;\n6CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_RETOOL\x10\xa2\x39\x12\x33\n.CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_RETOOL\x10\xac\x39\x12=\n8CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_RETOOL\x10\xb6\x39\x12\x30\n+CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_RETOOL\x10\xc0\x39\x12P\nKCLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_RETOOL\x10\xca\x39\x12_\nZCLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_RETOOL\x10\xd4\x39\x12\x31\n,CLASSIFICATION_TYPE_SUICIDE_PROMOTION_RETOOL\x10\xde\x39\x12H\nCCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_RETOOL\x10\xe8\x39\x12N\nICLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_RETOOL\x10\xf2\x39\x12<\n7CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_RETOOL\x10\xfc\x39\x12P\nKCLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_RETOOL\x10\x86:\x12\x31\n,CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_RETOOL\x10\x90:\x12]\nXCLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_RETOOL\x10\xa5\x38\x12=\n8CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_RETOOL\x10\xaf\x38\x12\x43\n>CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_RETOOL\x10\xb9\x38\x12`\n[CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_RETOOL\x10\xc3\x38\x12\x43\n>CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_RETOOL\x10\xcd\x38\x12N\nICLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_RETOOL\x10\xd7\x38\x12N\nICLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_RETOOL\x10\xe1\x38\x12[\nVCLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL\x10\xeb\x38\x12Z\nUCLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL\x10\xf5\x38\x12<\n7CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_GUILD_RETOOL\x10\xff\x38\x12R\nMCLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_RETOOL\x10\x89\x39\x12^\nYCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_RETOOL\x10\x93\x39\x12J\nECLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_RETOOL\x10\x9d\x39\x12\x41\n<CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_GUILD_RETOOL\x10\xa7\x39\x12\x39\n4CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_RETOOL\x10\xb1\x39\x12\x43\n>CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_RETOOL\x10\xbb\x39\x12\x36\n1CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_RETOOL\x10\xc5\x39\x12V\nQCLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_RETOOL\x10\xcf\x39\x12\x65\n`CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_RETOOL\x10\xd9\x39\x12\x37\n2CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_RETOOL\x10\xe3\x39\x12N\nICLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_RETOOL\x10\xed\x39\x12T\nOCLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_RETOOL\x10\xf7\x39\x12\x42\n=CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_RETOOL\x10\x81:\x12V\nQCLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_RETOOL\x10\x8b:\x12\x37\n2CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_RETOOL\x10\x95:\x12k\nfCLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_RETOOL\x10\xa6\x38\x12K\nFCLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_RETOOL\x10\xb0\x38\x12Q\nLCLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_RETOOL\x10\xba\x38\x12n\niCLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_RETOOL\x10\xc4\x38\x12Q\nLCLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_RETOOL\x10\xce\x38\x12\\\nWCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_RETOOL\x10\xd8\x38\x12\\\nWCLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_RETOOL\x10\xe2\x38\x12i\ndCLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL\x10\xec\x38\x12h\ncCLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL\x10\xf6\x38\x12J\nECLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_NON_DEDICATED_GUILD_RETOOL\x10\x80\x39\x12`\n[CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_NON_DEDICATED_GUILD_RETOOL\x10\x8a\x39\x12H\nCCLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_NON_DEDICATED_GUILD_RETOOL\x10\x9a\x37\x12l\ngCLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_RETOOL\x10\x94\x39\x12X\nSCLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_RETOOL\x10\x9e\x39\x12O\nJCLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_NON_DEDICATED_GUILD_RETOOL\x10\xa8\x39\x12G\nBCLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_RETOOL\x10\xb2\x39\x12Q\nLCLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_RETOOL\x10\xbc\x39\x12\x44\n?CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_RETOOL\x10\xc6\x39\x12\x64\n_CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_NON_DEDICATED_GUILD_RETOOL\x10\xd0\x39\x12s\nnCLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_RETOOL\x10\xda\x39\x12\x45\n@CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_RETOOL\x10\xe4\x39\x12\\\nWCLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_RETOOL\x10\xee\x39\x12\x62\n]CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_RETOOL\x10\xf8\x39\x12P\nKCLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_NON_DEDICATED_GUILD_RETOOL\x10\x82:\x12\x64\n_CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_RETOOL\x10\x8c:\x12\x45\n@CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_RETOOL\x10\x96:\x12\x37\n2CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_RETOOL\x10\x9a:\x12:\n5CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_RETOOL\x10\xa4:\x12=\n8CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_RETOOL\x10\x9f:\x12@\n;CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_RETOOL\x10\xa9:\x12K\nFCLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_RETOOL\x10\xa0:\x12N\nICLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_RETOOL\x10\xaa:\x12\x38\n3CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_RETOOL\x10\xae:\x12>\n9CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_RETOOL\x10\xb3:\x12U\nPCLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_SAFETY_DISPATCH\x10\xb8:\x12i\ndCLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_SAFETY_DISPATCH\x10\xbe:\x12K\nFCLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_ADMIN\x10\xc2:\x12_\nZCLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_ADMIN\x10\xc8:\x12P\nKCLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_HASH_MATCH\x10\xcc:\x12,\n\'CLASSIFICATION_TYPE_TEST_CLASSIFICATION\x10\xa8\x46\x12\x30\n+CLASSIFICATION_TYPE_TEST_CLASSIFICATION_LOW\x10\xa9\x46\x12\x33\n.CLASSIFICATION_TYPE_TEST_CLASSIFICATION_SEVERE\x10\xaa\x46\x12\x32\n-CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION\x10\x8cG\x12\x36\n1CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_LOW\x10\x8dG\x12\x39\n4CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_SEVERE\x10\x8eG\x12@\n;CLASSIFICATION_TYPE_TEST_PROVISIONAL_ACCOUNT_CLASSIFICATION\x10\xf0G\"\xb6\x06\n\x11SafetyStateReason\x12*\n&SAFETY_STATE_REASON_REASON_UNSPECIFIED\x10\x00\x12\x34\n0SAFETY_STATE_REASON_DISABLED_SUSPICIOUS_ACTIVITY\x10\x01\x12\x37\n3SAFETY_STATE_REASON_SMITE_REMOVE_EMAIL_VERIFICATION\x10\x02\x12G\nCSAFETY_STATE_REASON_USER_REQUIRED_VERIFICATION_INTERVENTIONS_CLIENT\x10\x03\x12\x33\n/SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_COMPLETED\x10\x04\x12\x31\n-SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_CREATED\x10\x05\x12\x33\n/SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CREATED\x10\x06\x12>\n:SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_UPGRADED_TO_ACTIVE\x10\x07\x12\x35\n1SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CANCELLED\x10\x08\x12\x31\n-SAFETY_STATE_REASON_ASSIGNMENT_STATE_REPAIRED\x10\t\x12,\n(SAFETY_STATE_REASON_MANUAL_PERMANENT_BAN\x10\n\x12+\n\'SAFETY_STATE_REASON_SAFETY_SYSTEM_UNBAN\x10\x0b\x12\x37\n3SAFETY_STATE_REASON_GENERIC_AUTOMATED_SAFETY_ACTION\x10\x0c\x12\x34\n0SAFETY_STATE_REASON_GENERIC_MANUAL_SAFETY_ACTION\x10\r\x12,\n(SAFETY_STATE_REASON_BANNED_USER_BACKFILL\x10\x0e\"\xd9\x02\n\x11SafetyAnnotations\x12-\n)SAFETY_ANNOTATIONS_ANNOTATION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aSAFETY_ANNOTATIONS_SPAMMER\x10\x01\x12#\n\x1fSAFETY_ANNOTATIONS_SELF_DELETED\x10\x02\x12$\n SAFETY_ANNOTATIONS_SELF_DISABLED\x10\x03\x12\'\n#SAFETY_ANNOTATIONS_UNDERAGE_DELETED\x10\x04\x12.\n*SAFETY_ANNOTATIONS_SAFETY_POLICY_VIOLATION\x10\x05\x12)\n%SAFETY_ANNOTATIONS_INACTIVITY_DELETED\x10\x06\x12&\n\"SAFETY_ANNOTATIONS_GENERIC_DELETED\x10\x07\"\xbb\x03\n\x0f\x44isplayNameFont\x12!\n\x1d\x44ISPLAY_NAME_FONT_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44ISPLAY_NAME_FONT_DEFAULT\x10\x0b\x12\x1d\n\x19\x44ISPLAY_NAME_FONT_BANGERS\x10\x01\x12\x1f\n\x1b\x44ISPLAY_NAME_FONT_BIO_RHYME\x10\x02\x12!\n\x1d\x44ISPLAY_NAME_FONT_CHERRY_BOMB\x10\x03\x12\x1c\n\x18\x44ISPLAY_NAME_FONT_CHICLE\x10\x04\x12\x1f\n\x1b\x44ISPLAY_NAME_FONT_COMPAGNON\x10\x05\x12#\n\x1f\x44ISPLAY_NAME_FONT_MUSEO_MODERNO\x10\x06\x12 \n\x1c\x44ISPLAY_NAME_FONT_NEO_CASTEL\x10\x07\x12\x1e\n\x1a\x44ISPLAY_NAME_FONT_PIXELIFY\x10\x08\x12\x1b\n\x17\x44ISPLAY_NAME_FONT_RIBES\x10\t\x12\x1e\n\x1a\x44ISPLAY_NAME_FONT_SINISTRE\x10\n\x12 \n\x1c\x44ISPLAY_NAME_FONT_ZILLA_SLAB\x10\x0c\"\xf0\x01\n\x11\x44isplayNameEffect\x12#\n\x1f\x44ISPLAY_NAME_EFFECT_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44ISPLAY_NAME_EFFECT_SOLID\x10\x01\x12 \n\x1c\x44ISPLAY_NAME_EFFECT_GRADIENT\x10\x02\x12\x1c\n\x18\x44ISPLAY_NAME_EFFECT_NEON\x10\x03\x12\x1c\n\x18\x44ISPLAY_NAME_EFFECT_TOON\x10\x04\x12\x1b\n\x17\x44ISPLAY_NAME_EFFECT_POP\x10\x05\x12\x1c\n\x18\x44ISPLAY_NAME_EFFECT_GLOW\x10\x06\x42\t\n\x07_avatarB\x0e\n\x0c_global_nameB\x19\n\x17_avatar_decoration_dataB\x10\n\x0e_primary_guildB\x0f\n\r_collectiblesB\x0f\n\r_safety_stateB\x16\n\x14_display_name_stylesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'users.v1.User_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USER']._serialized_start=115
  _globals['_USER']._serialized_end=40403
  _globals['_USER_USERAVATARDECORATION']._serialized_start=712
  _globals['_USER_USERAVATARDECORATION']._serialized_end=881
  _globals['_USER_USERPRIMARYGUILD']._serialized_start=884
  _globals['_USER_USERPRIMARYGUILD']._serialized_end=1182
  _globals['_USER_USERNAMEPLATE']._serialized_start=1185
  _globals['_USER_USERNAMEPLATE']._serialized_end=1377
  _globals['_USER_USERCOLLECTIBLES']._serialized_start=1379
  _globals['_USER_USERCOLLECTIBLES']._serialized_end=1480
  _globals['_USER_NORMALSTATE']._serialized_start=1482
  _globals['_USER_NORMALSTATE']._serialized_end=1495
  _globals['_USER_RESTRICTEDSTATE']._serialized_start=1497
  _globals['_USER_RESTRICTEDSTATE']._serialized_end=1594
  _globals['_USER_DEFERREDACTIONSTATE']._serialized_start=1596
  _globals['_USER_DEFERREDACTIONSTATE']._serialized_end=1707
  _globals['_USER_TEMPBANNEDSTATE']._serialized_start=1710
  _globals['_USER_TEMPBANNEDSTATE']._serialized_end=1879
  _globals['_USER_BANNEDSTATE']._serialized_start=1881
  _globals['_USER_BANNEDSTATE']._serialized_end=1974
  _globals['_USER_SAFETYSTATE']._serialized_start=1977
  _globals['_USER_SAFETYSTATE']._serialized_end=2555
  _globals['_USER_DISPLAYNAMESTYLES']._serialized_start=2558
  _globals['_USER_DISPLAYNAMESTYLES']._serialized_end=2725
  _globals['_USER_CLASSIFICATIONTYPE']._serialized_start=2729
  _globals['_USER_CLASSIFICATIONTYPE']._serialized_end=38411
  _globals['_USER_SAFETYSTATEREASON']._serialized_start=38414
  _globals['_USER_SAFETYSTATEREASON']._serialized_end=39236
  _globals['_USER_SAFETYANNOTATIONS']._serialized_start=39239
  _globals['_USER_SAFETYANNOTATIONS']._serialized_end=39584
  _globals['_USER_DISPLAYNAMEFONT']._serialized_start=39587
  _globals['_USER_DISPLAYNAMEFONT']._serialized_end=40030
  _globals['_USER_DISPLAYNAMEEFFECT']._serialized_start=40033
  _globals['_USER_DISPLAYNAMEEFFECT']._serialized_end=40273
# @@protoc_insertion_point(module_scope)
